@@ -1,11 +1,9 @@
 #ifndef _ENDIAN_H_
 #define _ENDIAN_H_
 
-#include <sys/types.h>
 
 #ifdef __cplusplus
-extern "C"
-{
+extern "C" {
 #endif
 
 
