@@ -3,8 +3,7 @@
 
 
 #ifdef __cplusplus
-extern "C"
-{
+extern "C" {
 #endif
 
 
@@ -39,8 +38,8 @@ extern "C"
 
 
 
-  extern int fmtmsg (long, const char *, int, const char *, const char *,
-		     const char *);
+    extern int fmtmsg(long int, const char *, int, const char *,
+		      const char *, const char *);
 #ifdef __cplusplus
 }
 #endif
