@@ -4,8 +4,7 @@
 #include <stddef.h>
 
 #ifdef __cplusplus
-extern "C"
-{
+extern "C" {
 #endif
 
 
@@ -15,12 +14,12 @@ extern "C"
 /* Identifier for conversion method from one codeset to another*/
 
 
-  typedef void *iconv_t;
+    typedef void *iconv_t;
 
 
-  extern size_t iconv (iconv_t, char **, size_t *, char **, size_t *);
-  extern int iconv_close (iconv_t);
-  extern iconv_t iconv_open (const char *, const char *);
+    extern size_t iconv(iconv_t, char **, size_t *, char **, size_t *);
+    extern int iconv_close(iconv_t);
+    extern iconv_t iconv_open(const char *, const char *);
 #ifdef __cplusplus
 }
 #endif
