@@ -3,8 +3,7 @@
 
 
 #ifdef __cplusplus
-extern "C"
-{
+extern "C" {
 #endif
 
 
@@ -16,15 +15,13 @@ extern "C"
 #define POLLNVAL	0x0020
 
 
-  struct pollfd
-  {
-    int fd;			/* File descriptor to poll. */
-    short events;		/* Types of events poller cares about. */
-    short revents;		/* Types of events that actually occurred. */
-  }
-   ;
+    typedef unsigned long int nfds_t;
 
-  typedef unsigned long nfds_t;
+    struct pollfd {
+	int fd;			/* File descriptor to poll. */
+	short events;		/* Types of events poller cares about. */
+	short revents;		/* Types of events that actually occurred. */
+    };
 
 
 #ifdef __cplusplus
