@@ -1,12 +1,9 @@
 #ifndef _SYS_TIMEX_H_
 #define _SYS_TIMEX_H_
 
-#include <sys/types.h>
-#include <sys/time.h>
 
 #ifdef __cplusplus
-extern "C"
-{
+extern "C" {
 #endif
 
 
