@@ -5,16 +5,15 @@
 #include <stddef.h>
 
 #ifdef __cplusplus
-extern "C"
-{
+extern "C" {
 #endif
 
 
 
 
 
-  extern ssize_t readv (int, const struct iovec *, int);
-  extern ssize_t writev (int, const struct iovec *, int);
+    extern ssize_t readv(int, const struct iovec *, int);
+    extern ssize_t writev(int, const struct iovec *, int);
 #ifdef __cplusplus
 }
 #endif
