@@ -4,20 +4,17 @@
 #include <sys/socket.h>
 
 #ifdef __cplusplus
-extern "C"
-{
+extern "C" {
 #endif
 
 
 #define UNIX_PATH_MAX	108
 
 
-  struct sockaddr_un
-  {
-    sa_family_t sun_family;	/* AF_UNIX */
-    char sun_path[UNIX_PATH_MAX];
-  }
-   ;
+    struct sockaddr_un {
+	sa_family_t sun_family;	/* AF_UNIX */
+	char sun_path[UNIX_PATH_MAX];
+    };
 
 
 #ifdef __cplusplus
