@@ -1,10 +1,15 @@
+void _Unwind_Backtrace() {} ;
 void _Unwind_DeleteException() {} ;
+void _Unwind_FindEnclosingFunction() {} ;
 void _Unwind_ForcedUnwind() {} ;
+void _Unwind_GetBSP() {} ;
+void _Unwind_GetCFA() {} ;
 void _Unwind_GetGR() {} ;
 void _Unwind_GetIP() {} ;
 void _Unwind_GetLanguageSpecificData() {} ;
 void _Unwind_GetRegionStart() {} ;
 void _Unwind_RaiseException() {} ;
 void _Unwind_Resume() {} ;
+void _Unwind_Resume_or_Rethrow() {} ;
 void _Unwind_SetGR() {} ;
 void _Unwind_SetIP() {} ;
