@@ -129,6 +129,7 @@ void dngettext() {} ;
 void drand48() {} ;
 void dup() {} ;
 void dup2() {} ;
+void duplocale() {} ;
 void ecvt() {} ;
 void endgrent() {} ;
 void endprotoent() {} ;
@@ -184,6 +185,7 @@ void fputws() {} ;
 void fread() {} ;
 void free() {} ;
 void freeaddrinfo() {} ;
+void freelocale() {} ;
 void freopen() {} ;
 void freopen64() {} ;
 void fscanf() {} ;
@@ -229,6 +231,7 @@ void getgrgid() {} ;
 void getgrgid_r() {} ;
 void getgrnam() {} ;
 void getgrnam_r() {} ;
+void getgrouplist() {} ;
 void getgroups() {} ;
 void gethostbyaddr() {} ;
 void gethostbyname() {} ;
@@ -358,7 +361,6 @@ void longjmp() {} ;
 void lrand48() {} ;
 void lsearch() {} ;
 void lseek() {} ;
-void lseek64() {} ;
 void makecontext() {} ;
 void malloc() {} ;
 void mblen() {} ;
@@ -398,6 +400,7 @@ void munlock() {} ;
 void munlockall() {} ;
 void munmap() {} ;
 void nanosleep() {} ;
+void newlocale() {} ;
 void nftw() {} ;
 void nftw64() {} ;
 void ngettext() {} ;
@@ -407,7 +410,6 @@ void nrand48() {} ;
 void ntohl() {} ;
 void ntohs() {} ;
 void open() {} ;
-void open64() {} ;
 void opendir() {} ;
 void openlog() {} ;
 void pathconf() {} ;
@@ -421,6 +423,7 @@ void pmap_unset() {} ;
 void poll() {} ;
 void popen() {} ;
 void posix_memalign() {} ;
+void posix_openpt() {} ;
 void printf() {} ;
 void psignal() {} ;
 void ptsname() {} ;
@@ -660,6 +663,7 @@ void ungetwc() {} ;
 void unlink() {} ;
 void unlockpt() {} ;
 void unsetenv() {} ;
+void uselocale() {} ;
 void usleep() {} ;
 void utime() {} ;
 void utimes() {} ;
@@ -786,9 +790,6 @@ __asm__(".comm _sys_siglist,0");
 __asm__(".weak daylight; daylight = __daylight");
 __asm__(".weak environ; environ = __environ");
 __asm__(".comm getdate_err,4");
-__asm__(".comm loc1,8");
-__asm__(".comm loc2,8");
-__asm__(".comm locs,8");
 __asm__(".comm optarg,8");
 __asm__(".comm opterr,4");
 __asm__(".comm optind,4");
